==> lcscatter-1.1.3.tgz: package/src/ScatterExplorer.js <==

const { Api,
    JsonRpc,
    ecc } = require('lcnjs')

class ScatterExplorer {
    constructor() {
        this.info = this.getInfo()
    }

    static async getInfo() {
        let account = await window.scatter.sign.getInfo()
        return account
    }

    static loadScatter() {
        return new Promise((resolve,reject)=>{
            window.sid = setTimeout(async () => {
                if (window.scatter) {
                    let account = await this.getInfo()
                    window.accountInfo = account
                    let endpoint = account && account.endpointsrvlist ? account.endpointsrvlist[0] : 'http://39.106.5.40/chain'
                    const rpc = new JsonRpc(endpoint, {
                        fetch
                    })
                    const lcn = new Api({
                        rpc,
                        signatureProvider: window.scatter.sign,
                        textDecoder: new TextDecoder(),
                        textEncoder: new TextEncoder()
                    })
                    window.lcn = lcn
                    return resolve(lcn)
                }else{
                    return reject('您未安装钱包或钱包异常')
                }
            }, 1000)
            document.addEventListener('scatterLoaded', async scatterExtension => {
                clearTimeout(window.sid)
                if (window.scatter) {
                    let account = await this.getInfo()
                    window.accountInfo = account
                    let endpoint = account && account.endpointsrvlist ? account.endpointsrvlist[0] : 'http://39.106.5.40/chain'
                    const rpc = new JsonRpc(endpoint, {
                        fetch
                    })
                    const lcn = new Api({
                        rpc,
                        signatureProvider: window.scatter.sign,
                        textDecoder: new TextDecoder(),
                        textEncoder: new TextEncoder()
                    })
                    window.lcn = lcn
                    return resolve(lcn)
                }else{
                    return reject('您未安装钱包或钱包异常')
                }
            })
        })
       
    }

}

module.exports = ScatterExplorer

==> lcscatter-1.2.2.tgz: package/src/ScatterExplorer.js <==

const { Api,
    JsonRpc,
    ecc } = require('lcnjs')

class ScatterExplorer {
    constructor() {
        this.info = this.getInfo()
    }

    static async getInfo() {
        let account = await window.scatter.sign.getInfo()
        return account
    }

    static loadScatter() {
        return new Promise((resolve,reject)=>{
            window.sid = setTimeout(async () => {
                debugger
                if (window.scatter) {
                    let account = await this.getInfo()
                    window.accountInfo = account
                    let endpoint = account && account.endpointsrvlist ? account.endpointsrvlist[0] : 'http://39.106.5.40/chain'
                    const rpc = new JsonRpc(endpoint, {
                        fetch
                    })
                    const lcn = new Api({
                        rpc,
                        signatureProvider: window.scatter.sign,
                        textDecoder: new TextDecoder(),
                        textEncoder: new TextEncoder()
                    })
                    window.lcn = lcn
                     resolve(lcn)
                }else{
                 reject('您未安装钱包或钱包异常')
                }
            }, 1000)
            document.addEventListener('scatterLoaded', async scatterExtension => {
                clearTimeout(window.sid)
                if (window.scatter) {
                    let account = await this.getInfo()
                    window.accountInfo = account
                    let endpoint = account && account.endpointsrvlist ? account.endpointsrvlist[0] : 'http://39.106.5.40/chain'
                    const rpc = new JsonRpc(endpoint, {
                        fetch
                    })
                    const lcn = new Api({
                        rpc,
                        signatureProvider: window.scatter.sign,
                        textDecoder: new TextDecoder(),
                        textEncoder: new TextEncoder()
                    })
                    window.lcn = lcn
                     resolve(lcn)
                }else{
                     reject('您未安装钱包或钱包异常')
                }
            })
        })
       
    }

}

module.exports = ScatterExplorer
